function [IMG] = measureI(I,depth,threshold)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % -----USAGE-----
    % 1) Method call with inputs:       when the method is called with two
    % inputs, they must follow the below convention.
    % 
    % -----DEFS-----
    % INPUTS: I         =   image read from imread.
    %         depth     =   bit depth of the image. this is needed so that
    %                       the iamge can be properly normalized.
    %         threshold =   threshold value for performing the
    %                       binarization. if the threshold is an empty
    %                       array, then otsu will be called to obtain a
    %                       threshold value.
    % --------------------------------------------------
    % FLAGS:  disp      =   flag for displaying the image and scattering
    %                       the points onto the image. The scattered values
    %                       are the centroids for the seeds.
    %         ratioFilter = The threshold value for the ratio between the
    %                       model and the measured. A perfect match would
    %                       be 1, where model = measure.
    %         mMfilter  =   The filter value for thresholding major to
    %                       minor.
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    %%%%%%%%%%%%%%%%%%%%
    % FLAGS
    disp = 0;
    ratioFilter = 1.1;
    mMfilter = 2.5;
    %%%%%%%%%%%%%%%%%%%%
    try
        
        %%%%%%%%%%%%%%%%%%%%
        % declare data structure
        IMG.SeedSheet = [];
        IMG.threshold = [];
        IMG.SeedCount = [];
        IMG.Percent_Clusters = [];
        %%%%%%%%%%%%%%%%%%%%
        % if color then make grayscale
        if size(I,3) == 3
            I = rgb2gray(I);
        end
        %%%%%%%%%%%%%%%%%%%%
        % normalize image
        if ~strcmp(class(I),'double')
            I = double(I);
            I = I * 2^-(depth);
        end
        %%%%%%%%%%%%%%%%%%%%
        % get the threshold
        if size(threshold,1) == 0
            threshold = graythresh(I);
        end    
        BW = I < threshold;
        BW = bwareaopen(BW,500);
        %%%%%%%%%%%%%%%%%%%%
        % label and measure            
        CC = bwconncomp(BW,8);        
        R = regionprops(CC,'Area','MinorAxisLength','MajorAxisLength','Centroid');        
        %%%%%%%%%%%%%%%%%%%%
        % perform the histogram
        bins = linspace(0,20000,200);
        v = hist([R.Area],bins);
        [JUNK xpos] = max(v);
        SSS = bins(xpos);           % single seed size
        SPC = round([R.Area]/SSS);  % seeds per cluster    
        NUM_SEEDS = sum(SPC);       % number of seeds
        sidx = find(SPC==1);
        M = [[R(sidx).Area]' [R(sidx).MinorAxisLength]' [R(sidx).MajorAxisLength]'];        
        %%%%%%%%%%%%%%%%%%%%
        % compute percent
        U = unique(SPC);    
        for i = 1:size(U,2)
            TYPE(i) = sum(SPC == U(i));
        end 
        %%%%%%%%%%%%%%%%%%%%
        % fill out object
        IMG.SeedSheet = M;
        IMG.threshold = threshold;
        IMG.SeedCount = NUM_SEEDS;
        IMG.Percent_Clusters = TYPE.*U * NUM_SEEDS^-1;      
        RATIO = (IMG.SeedSheet(:,2).*IMG.SeedSheet(:,3)*pi/4.*IMG.SeedSheet(:,1).^-1);
        A = find(RATIO < ratioFilter & (IMG.SeedSheet(:,3).*IMG.SeedSheet(:,2).^-1 < mMfilter));
        IMG.SeedSheet = IMG.SeedSheet(A,:);
        IMG.SeedCount = size(IMG.SeedSheet,1);
        %%%%%%%%%%%%%%%%%%%%
        % if display
        if disp
            imshow(I,[])
            hold on
            for i = 1:size(A,1)
                scatter(R(sidx(A(i))).Centroid(:,1),R(sidx(A(i))).Centroid(:,2),'o')        
            end    
            drawnow
            hold off
        end
    catch ME
        ME
    end
    
end
